@@ -7,8 +7,8 @@ import (
 	"os"
 	"path/filepath"
 
-	"github.com/openshift/origin/pkg/cmd/util/gendocs"
-	"github.com/openshift/origin/pkg/oc/cli"
+	"github.com/openshift/oc/pkg/cli"
+	"github.com/openshift/oc/tools/gendocs/gendocs"
 )
 
 func OutDir(path string) (string, error) {
